package dao;

import entidades.EmpresaPeriodo;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.faces.model.SelectItem;
import util.ConexaoFactory;


public class EmpresaPeriodoDAO {

    private Connection conn;

    /**
     *
     * @throws JogosDAOException
     */
    public EmpresaPeriodoDAO() throws JogosDAOException {
        try {
            this.conn = ConexaoFactory.getConnection();
        } catch (Exception e) {
            throw new JogosDAOException("Erro: " + ": \n" + e.getMessage());
        }
    }


    /**
     *
     * @param empresaperiodo
     * @throws JogosDAOException
     */
    public void salvar(EmpresaPeriodo empresaperiodo) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (empresaperiodo == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - ins.");
        }

        try {
            String SQL = "insert into empresa_periodo (em_pe_id, em_e_id, em_nome) "
                    + "values (?,?,?)";
            conne = this.conn;
            ps = conne.prepareStatement(SQL);
            ps.setInt(1, empresaperiodo.getEm_pe_id());
            ps.setInt(2, empresaperiodo.getEm_e_id());
            ps.setString(3, empresaperiodo.getEm_nome());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao inserir dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }


    /**
     *
     * @param empresaperiodo
     * @throws JogosDAOException
     */
    public void excluir(EmpresaPeriodo empresaperiodo) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (empresaperiodo == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - exc.");
        }

        try {
            conne = this.conn;
            ps = conne.prepareStatement("delete from empresa_periodo where em_id=?");
            ps.setInt(1, empresaperiodo.getEm_id());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao excluir dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }


    /**
     *
     * @param empresaperiodo
     * @throws JogosDAOException
     */
    public void atualizar(EmpresaPeriodo empresaperiodo) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (empresaperiodo == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - alt.");
        }
        try {
            String SQL = "update empresa_periodo set "
                        + "em_noStatus = null "
                        + "where em_e_id=? and em_tu_id = ?";
            conne = this.conn;
            ps = conne.prepareStatement(SQL);
            ps.setInt(1, empresaperiodo.getEm_e_id());
            ps.setInt(2, empresaperiodo.getEm_tu_id());
            ps.executeUpdate();

            SQL = "update empresa_periodo set "
                    + "em_nome = ?, "
                    + "em_noStatus = ?, "
                    + "em_pe_id = ?, "
                    + "em_e_id= ? "
                    + "where em_id=?";
            conne = this.conn;
            ps = conne.prepareStatement(SQL);
            ps.setString(1, empresaperiodo.getEm_nome());
            ps.setString(2, empresaperiodo.getEm_noStatus());
            ps.setInt(3, empresaperiodo.getEm_pe_id());
            ps.setInt(4, empresaperiodo.getEm_e_id());
            ps.setInt(5, empresaperiodo.getEm_id());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao atualizar dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }

    public void atualizarCalculado(EmpresaPeriodo empresaperiodo) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (empresaperiodo == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - alt.");
        }
        try {
            String SQL = "update empresa_periodo set "
                    + "em_pe_id = ?, "
                    + "em_nome = ?, "
                    + "em_e_id = ?, "
                    + "em_tu_id = ?, "
                    + "em_nrPeriodo = ?, "
                    + "em_nrEmpresa = ?, "
                    + "em_noStatus = ? "
                    + "where em_id=?";
            conne = this.conn;
            ps = conne.prepareStatement(SQL);
            ps.setInt(1, empresaperiodo.getEm_pe_id());
            ps.setString(2, empresaperiodo.getEm_nome());
            ps.setInt(3, empresaperiodo.getEm_e_id());
            ps.setInt(4, empresaperiodo.getEm_tu_id());
            ps.setInt(5, empresaperiodo.getEm_nrPeriodo());
            ps.setInt(6, empresaperiodo.getEm_nrEmpresa());
            ps.setString(7, empresaperiodo.getEm_noStatus());
            ps.setInt(8, empresaperiodo.getEm_id());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao atualizar dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }


    public EmpresaPeriodo listaByEmpPer(int emp, int per) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            ps = conne.prepareStatement("select em_id,  em_nome, em_pe_id, em_e_id, em_noStatus, em_tu_id from empresa_periodo where em_e_id = ? and em_pe_id = ?");
            ps.setInt(1, emp);
            ps.setInt(2, per);
            rs = ps.executeQuery();

            if (!rs.next()) {
                throw new JogosDAOException("Nao foi encontrado nenhum registro com o id: " + emp);
            }

            EmpresaPeriodo empresaperiodo = new EmpresaPeriodo();
            int i = 1;
            empresaperiodo.setEm_id(rs.getInt(i++));
            empresaperiodo.setEm_nome(rs.getString(i++));
            empresaperiodo.setEm_pe_id(rs.getInt(i++));
            empresaperiodo.setEm_e_id(rs.getInt(i++));
            empresaperiodo.setEm_noStatus(rs.getString(i++));
            empresaperiodo.setEm_tu_id(rs.getInt(i++));


            return empresaperiodo;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }

    public List listaByPeriodo(int pe_id) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            ps = conne.prepareStatement("select em_id, em_pe_id, em_nome, em_e_id, em_tu_id, em_nrPeriodo, em_nrEmpresa, em_noStatus from empresa_periodo where em_pe_id = " + pe_id);
            rs = ps.executeQuery();
            List<EmpresaPeriodo> lista = new ArrayList<EmpresaPeriodo>();
            while (rs.next()) {
                EmpresaPeriodo em = new EmpresaPeriodo();
                em.setEm_id(rs.getInt(1));
                em.setEm_pe_id(rs.getInt(2));
                em.setEm_nome(rs.getString(3));
                em.setEm_e_id(rs.getInt(4));
                em.setEm_tu_id(rs.getInt(5));
                em.setEm_nrPeriodo(rs.getInt(6));
                em.setEm_nrEmpresa(rs.getInt(7));
                em.setEm_noStatus(rs.getString(8));
                lista.add(em);
            }
            return lista;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }


    /**
     *
     * @param emp
     * @param turma
     * @return
     * @throws JogosDAOException
     */
    public EmpresaPeriodo listaByEmpTurmaAtiv(int emp, int turma) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            String sql = "select em_id,  em_nome, em_pe_id, em_e_id, coalesce(em_noStatus, p.pe_noStatus), ep.em_tu_id from periodo p "
                    + "join empresa_periodo ep on ep.em_pe_id = p.pe_id "
                    + "where coalesce(em_noStatus, p.pe_noStatus) = 'Aberto' and em_e_id = " + emp + " and pe_tu_id = " + turma;

            ps = conne.prepareStatement(sql);
            rs = ps.executeQuery();
            if (!rs.next()) {
                throw new JogosDAOException("Nao foi encontrado nenhum registro para função listaByEmpTurmaAtiv empresa" + emp + " turma" + turma);
            }

            EmpresaPeriodo empresaperiodo = new EmpresaPeriodo();
            int i = 1;
            empresaperiodo.setEm_id(rs.getInt(i++));
            empresaperiodo.setEm_nome(rs.getString(i++));
            empresaperiodo.setEm_pe_id(rs.getInt(i++));
            empresaperiodo.setEm_e_id(rs.getInt(i++));
            empresaperiodo.setEm_noStatus(rs.getString(i++));
            empresaperiodo.setEm_tu_id(rs.getInt(i++));
            List<EmpresaPeriodo> lista = new ArrayList<EmpresaPeriodo>();
            lista.add(empresaperiodo);
            return empresaperiodo;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }


    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public List<SelectItem> listaForMenu() throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            ps = conne.prepareStatement("select * from empresa_periodo");
            rs = ps.executeQuery();
            List<SelectItem> lista = new ArrayList<SelectItem>();

            while (rs.next()) {
                SelectItem empresaperiodo = new SelectItem(rs.getString(1), rs.getString(3));
                lista.add(empresaperiodo);
            }
            return lista;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }

    /**
     *
     * @param em_id
     * @return
     * @throws JogosDAOException
     */
    public EmpresaPeriodo empresaById(int em_id) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            String sql = "SELECT em_id,  em_pe_id, em_nome, em_e_id, em_tu_id, em_nrPeriodo, em_nrEmpresa, em_noStatus from empresa_periodo WHERE em_id = " + em_id;

            ps = conne.prepareStatement(sql);

            rs = ps.executeQuery();
            EmpresaPeriodo empresaperiodo = new EmpresaPeriodo();
            int i = 1;
            if (rs.next()) {
                empresaperiodo.setEm_id(rs.getInt(i++));
                empresaperiodo.setEm_pe_id(rs.getInt(i++));
                empresaperiodo.setEm_nome(rs.getString(i++));
                empresaperiodo.setEm_e_id(rs.getInt(i++));
                empresaperiodo.setEm_tu_id(rs.getInt(i++));
                empresaperiodo.setEm_nrPeriodo(rs.getInt(i++));
                empresaperiodo.setEm_nrEmpresa(rs.getInt(i++));
                empresaperiodo.setEm_noStatus(rs.getString(i++));
            }
            return empresaperiodo;
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao inserir dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }

    /**
     *
     * @param pe_id
     * @param em_nome
     * @return
     * @throws JogosDAOException
     */
    public EmpresaPeriodo empresaPeriodoAnterior(int pe_id, String em_nome) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            String sql = "SELECT  em_id,  em_nome, em_pe_id, em_e_id, em_noStatus, em_tu_id from empresa_periodo WHERE em_pe_id = " + pe_id + " AND em_nome= '" + em_nome + "'";

            ps = conne.prepareStatement(sql);

            rs = ps.executeQuery();
            EmpresaPeriodo empresaperiodo = new EmpresaPeriodo();
            int i = 1;
            if (rs.next()) {
                empresaperiodo.setEm_id(rs.getInt(i++));
                empresaperiodo.setEm_nome(rs.getString(i++));
                empresaperiodo.setEm_pe_id(rs.getInt(i++));
                empresaperiodo.setEm_e_id(rs.getInt(i++));
                empresaperiodo.setEm_noStatus(rs.getString(i++));
                empresaperiodo.setEm_tu_id(rs.getInt(i++));
            }
            return empresaperiodo;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }

    public int verificarCalculados(int pe_id) throws JogosDAOException{
        int calculado = 0;
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            String sql = "SELECT COUNT(*) FROM empresa_periodo WHERE em_noStatus = 'Fechado' AND em_pe_id = " + pe_id;

            ps = conne.prepareStatement(sql);

            rs = ps.executeQuery();
            if (rs.next()) {
                calculado = rs.getInt(1);

            }
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
        return calculado;
    }

/*    public static void main(String args[]) throws JogosDAOException{
        EmpresaPeriodoDAO emDAO = new EmpresaPeriodoDAO();
        EmpresaPeriodo em = emDAO.empresaById(1361);
        em.setEm_calculado(1);
        emDAO = new EmpresaPeriodoDAO();
        emDAO.atualizarCalculado(em);
    }*/
}
