/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package dao;

import entidades.Turma;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.faces.model.SelectItem;
import util.ConexaoFactory;

/**
 *
 * @author Doglei
 */
public class TurmaDAO {

    private Connection conn;

    /**
     *
     * @throws JogosDAOException
     */
    public TurmaDAO() throws JogosDAOException {
        try {
            this.conn = ConexaoFactory.getConnection();
        } catch (Exception e) {
            throw new JogosDAOException("Erro: " + ": \n" + e.getMessage());
        }
    }

    /**
     *
     * @param turma
     * @throws JogosDAOException
     */
    public void salvar(Turma turma) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (turma == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - ins.");
        }

        try {
            String SQL = "insert into turma (tu_noTurma, tu_noApelido, tu_nrAno, tu_nrSemestre, tu_fgAtiva, tu_co_id) "
                    + "values (?,?,?,?,?, ?)";
            conne = this.conn;
            ps = conne.prepareStatement(SQL);
            ps.setString(1, turma.getTu_noTurma());
            ps.setString(2, turma.getTu_noApelido());
            ps.setInt(3, turma.getTu_nrAno());
            ps.setInt(4, turma.getTu_nrSemestre());
            ps.setBoolean(5, turma.getTu_fgAtiva());
            ps.setInt(6, turma.getTu_co_id());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao inserir dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }

    /**
     *
     * @param turma
     * @throws JogosDAOException
     */
    public void excluir(Turma turma) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (turma == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - exc.");
        }

        try {
            conne = this.conn;
            ps = conne.prepareStatement("delete from turma where tu_id = ?");
            ps.setInt(1, turma.getTu_id());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao excluir dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }

    /**
     *
     * @param turma
     * @throws JogosDAOException
     */
    public void atualizar(Turma turma) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        if (turma == null) {
            throw new JogosDAOException("O valor passado não pode ser nulo - alt.");
        }

        try {
            String SQL = "update turma set "
                    + "tu_noTurma = ?, "
                    + "tu_noApelido = ?, "
                    + "tu_nrAno = ?, "
                    + "tu_nrSemestre = ?, "
                    + "tu_fgAtiva = ? "
                    + "where tu_id=?";
            conne = this.conn;
            ps = conne.prepareStatement(SQL);
            ps.setString(1, turma.getTu_noTurma());
            ps.setString(2, turma.getTu_noApelido());
            ps.setInt(3, turma.getTu_nrAno());
            ps.setInt(4, turma.getTu_nrSemestre());
            ps.setBoolean(5, turma.getTu_fgAtiva());
            ps.setInt(6, turma.getTu_id());
            ps.executeUpdate();
        } catch (SQLException sqle) {
            throw new JogosDAOException("Erro ao atualizar dados " + sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps);
        }
    }

    /**
     *
     * @param co_id
     * @return
     * @throws JogosDAOException
     */
    public List listaTodos(int co_id) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            ps = conne.prepareStatement("select tu_id, tu_noTurma, tu_noApelido, tu_nrAno, "
                    + "tu_nrSemestre, tu_fgAtiva from turma  where tu_co_id = " + co_id);
            rs = ps.executeQuery();
            List<Turma> lista = new ArrayList<Turma>();

            while (rs.next()) {
                Turma turma = new Turma();
                turma.setTu_id(rs.getInt(1));
                turma.setTu_noTurma(rs.getString(2));
                turma.setTu_noApelido(rs.getString(3));
                turma.setTu_nrAno(rs.getInt(4));
                turma.setTu_nrSemestre(rs.getInt(5));
                turma.setTu_fgAtiva(rs.getBoolean(6));
                lista.add(turma);
            }
            return lista;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }

    /**
     *
     * @param id
     * @return
     * @throws JogosDAOException
     */
    public Turma listaById(int id) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            ps = conne.prepareStatement("select tu_id, tu_noTurma, tu_noApelido, tu_nrAno, "
                    + "tu_nrSemestre, tu_fgAtiva from turma where tu_id = ?");
            ps.setInt(1, id);
            rs = ps.executeQuery();

            if (!rs.next()) {
                throw new JogosDAOException("Nao foi encontrado nenhum registro com o id: turmaDAO listById" + id);
            }
            Turma turma = new Turma();
            turma.setTu_id(rs.getInt(1));
            turma.setTu_noTurma(rs.getString(2));
            turma.setTu_noApelido(rs.getString(3));
            turma.setTu_nrAno(rs.getInt(4));
            turma.setTu_nrSemestre(rs.getInt(5));
            turma.setTu_fgAtiva(rs.getBoolean(6));
            return turma;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }

    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public List<SelectItem> listaForMenu() throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;
            ps = conne.prepareStatement("select tu_id, tu_noApelido from turma where tu_fgAtiva = 1 "
                    + "order by tu_noApelido");
            rs = ps.executeQuery();
            List<SelectItem> lista = new ArrayList<SelectItem>();

            while (rs.next()) {
                SelectItem turma = new SelectItem(rs.getString(1), rs.getString(2));
                lista.add(turma);
            }
            return lista;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }

    /**
     *
     * @param co_id
     * @return
     * @throws JogosDAOException
     */
    public List<Turma> listaForCoor(int co_id) throws JogosDAOException {
        PreparedStatement ps = null;
        Connection conne = null;
        ResultSet rs = null;
        try {
            conne = this.conn;

            List<Turma> lista = new ArrayList<Turma>();
            Turma tu;
            ps = conne.prepareStatement("select tu_id, tu_noApelido from turma where tu_fgAtiva = 1 and tu_co_id = " + co_id
                    + " order by tu_noApelido");
            rs = ps.executeQuery();
            while (rs.next()) {
                tu = new Turma();
                tu.setTu_id(rs.getInt(1));
                tu.setTu_noApelido(rs.getString(2));
                lista.add(tu);
            }

            return lista;
        } catch (SQLException sqle) {
            throw new JogosDAOException(sqle);
        } finally {
            ConexaoFactory.closeConnection(conne, ps, rs);
        }
    }
}
