﻿SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `mydb` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci ;
CREATE SCHEMA IF NOT EXISTS `ejogos` DEFAULT CHARACTER SET latin1 ;
USE `mydb` ;
USE `ejogos` ;

-- -----------------------------------------------------
-- Table `ejogos`.`tipocompramp`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`tipocompramp` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`tipocompramp` (
  `tcm_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `tcm_nome` VARCHAR(45) NULL DEFAULT NULL ,
  `tcm_noParc` INT(11) NULL DEFAULT NULL ,
  `tcm_enTipo` ENUM('C','V','E') NULL DEFAULT NULL ,
  PRIMARY KEY (`tcm_id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`empresa`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`empresa` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`empresa` (
  `e_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `e_descr` VARCHAR(45) NULL DEFAULT NULL ,
  PRIMARY KEY (`e_id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`usuario`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`usuario` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`usuario` (
  `us_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `us_noSenha` VARCHAR(32) NOT NULL ,
  `us_noEmail` VARCHAR(255) NOT NULL ,
  `us_noUsuario` VARCHAR(150) NOT NULL ,
  PRIMARY KEY (`us_id`) ,
  UNIQUE INDEX `us_noEmail_UNIQUE` (`us_noEmail` ASC) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`coordenador`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`coordenador` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`coordenador` (
  `co_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `co_chave_acesso` CHAR(6) NULL DEFAULT NULL ,
  `co_us_id` INT(11) NOT NULL ,
  PRIMARY KEY (`co_id`) ,
  INDEX `fk_coordenador_usuario1` (`co_us_id` ASC) ,
  CONSTRAINT `fk_coordenador_usuario1`
    FOREIGN KEY (`co_us_id` )
    REFERENCES `ejogos`.`usuario` (`us_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`turma`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`turma` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`turma` (
  `tu_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `tu_noTurma` VARCHAR(100) NOT NULL ,
  `tu_noApelido` VARCHAR(45) NULL DEFAULT NULL ,
  `tu_nrAno` INT(11) NULL DEFAULT NULL ,
  `tu_nrSemestre` INT(11) NULL DEFAULT NULL ,
  `tu_fgAtiva` TINYINT(1) NULL DEFAULT NULL ,
  `tu_co_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`tu_id`) ,
  UNIQUE INDEX `iu_turma_tu_id` (`tu_id` ASC) ,
  UNIQUE INDEX `iu_turma_noTurma` (`tu_noTurma` ASC) ,
  INDEX `fk_turma_coordenador1` (`tu_co_id` ASC) ,
  CONSTRAINT `fk_turma_coordenador1`
    FOREIGN KEY (`tu_co_id` )
    REFERENCES `ejogos`.`coordenador` (`co_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`periodo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`periodo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`periodo` (
  `pe_tu_id` INT(11) NOT NULL ,
  `pe_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `pe_noPeriodo` VARCHAR(45) NULL DEFAULT NULL ,
  `pe_noStatus` ENUM('Fechado','Aberto','Encerrado') NULL DEFAULT NULL ,
  `pe_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`pe_id`, `pe_tu_id`) ,
  INDEX `fk_pe_tu_id` (`pe_tu_id` ASC) ,
  CONSTRAINT `fk_pe_tu_id`
    FOREIGN KEY (`pe_tu_id` )
    REFERENCES `ejogos`.`turma` (`tu_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`empresa_periodo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`empresa_periodo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`empresa_periodo` (
  `em_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `em_pe_id` INT(11) NOT NULL ,
  `em_nome` VARCHAR(45) NULL DEFAULT NULL ,
  `em_e_id` INT(11) NOT NULL ,
  `em_tu_id` INT(11) NULL DEFAULT NULL ,
  `em_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `em_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  `em_noStatus` ENUM('Aberto','Fechado','Encerrado') NULL DEFAULT NULL ,
  PRIMARY KEY (`em_id`) ,
  INDEX `fk_empresa_em_pe_id` (`em_pe_id` ASC) ,
  INDEX `fk_empresa_periodo_empresa1` (`em_e_id` ASC) ,
  INDEX `fk_empresa_periodo_empresa` (`em_e_id` ASC) ,
  INDEX `fk_empresa_em_e_id` (`em_e_id` ASC) ,
  CONSTRAINT `fk_empresa_em_e_id`
    FOREIGN KEY (`em_e_id` )
    REFERENCES `ejogos`.`empresa` (`e_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_empresa_em_pe_id`
    FOREIGN KEY (`em_pe_id` )
    REFERENCES `ejogos`.`periodo` (`pe_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`emprestimo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`emprestimo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`emprestimo` (
  `ep_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `ep_em_id` INT(11) NOT NULL ,
  `ep_vlMaxEmp` DECIMAL(15,2) NULL DEFAULT NULL ,
  `ep_tcm_id` INT(11) NULL DEFAULT NULL ,
  `ep_vlEmprestimo` DECIMAL(15,2) NULL DEFAULT NULL ,
  `ep_tu_id` INT(11) NULL DEFAULT NULL ,
  `ep_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `ep_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`ep_id`) ,
  INDEX `fk_emprestimo_ep_em_id` (`ep_em_id` ASC) ,
  INDEX `fk_emprestimo_ep_tcm_id` (`ep_tcm_id` ASC) ,
  CONSTRAINT `fk_emprestimo_ep_em_id`
    FOREIGN KEY (`ep_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_emprestimo_ep_tcm_id`
    FOREIGN KEY (`ep_tcm_id` )
    REFERENCES `ejogos`.`tipocompramp` (`tcm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`amortizacao`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`amortizacao` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`amortizacao` (
  `esp_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `esp_em_id` INT(11) NOT NULL ,
  `esp_ep_id` INT(11) NOT NULL ,
  `esp_tcm_id` INT(11) NOT NULL ,
  `esp_vlEmprestimo` DECIMAL(15,2) NULL DEFAULT NULL ,
  `esp_vlAmortizacao` DECIMAL(15,2) NULL DEFAULT NULL ,
  `esp_vlJuros` DECIMAL(15,2) NULL DEFAULT NULL ,
  `esp_vlSaldoDevedor` DECIMAL(15,2) NULL DEFAULT NULL ,
  `esp_tu_id` INT(11) NULL DEFAULT NULL ,
  `esp_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `esp_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`esp_id`) ,
  INDEX `fk_amort_emp_especial_esp_em_id` (`esp_em_id` ASC) ,
  INDEX `fk_amort_emp_especial_esp_ep_id` (`esp_ep_id` ASC) ,
  INDEX `fk_amortizacao_tipocompramp1` (`esp_tcm_id` ASC) ,
  CONSTRAINT `fk_amortizacao_tipocompramp1`
    FOREIGN KEY (`esp_tcm_id` )
    REFERENCES `ejogos`.`tipocompramp` (`tcm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_amort_emp_especial_esp_em_id`
    FOREIGN KEY (`esp_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_amort_emp_especial_esp_ep_id`
    FOREIGN KEY (`esp_ep_id` )
    REFERENCES `ejogos`.`emprestimo` (`ep_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`tipomaquina`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`tipomaquina` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`tipomaquina` (
  `tm_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `tm_noTipo` VARCHAR(10) NULL DEFAULT NULL ,
  `tm_qtCapacidade` INT(11) NULL DEFAULT NULL ,
  `tm_qtEmpregados` INT(11) NULL DEFAULT NULL ,
  `tm_pcCustoManut` DECIMAL(15,2) NULL DEFAULT NULL ,
  `tm_vlInicial` DECIMAL(15,2) NULL DEFAULT NULL ,
  PRIMARY KEY (`tm_id`) ,
  UNIQUE INDEX `ui_tipomaquina_tm_id` (`tm_id` ASC) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`compra_venda_maquina`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`compra_venda_maquina` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`compra_venda_maquina` (
  `cvm_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `cvm_pe_id` INT(11) NOT NULL ,
  `cvm_em_id` INT(11) NOT NULL ,
  `cvm_tm_id` INT(11) NOT NULL ,
  `cvm_noTipoTransacao` ENUM('C','V') NOT NULL ,
  `cvm_nrQtde` INT(11) NOT NULL ,
  PRIMARY KEY (`cvm_id`) ,
  INDEX `fk_compravenda_empresapriodo_em_id` (`cvm_em_id` ASC) ,
  INDEX `fk_compravenda_tipomaquina` (`cvm_tm_id` ASC) ,
  CONSTRAINT `fk_compravenda_empresapriodo_em_id`
    FOREIGN KEY (`cvm_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_compravenda_tipomaquina`
    FOREIGN KEY (`cvm_tm_id` )
    REFERENCES `ejogos`.`tipomaquina` (`tm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`compramp`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`compramp` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`compramp` (
  `cmp_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `cmp_em_id` INT(11) NOT NULL ,
  `cmp_tcm_id` INT(11) NULL DEFAULT NULL ,
  `cmp_tu_id` INT(11) NULL DEFAULT NULL ,
  `cmp_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `cmp_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`cmp_id`) ,
  INDEX `fk_compramp_cmp_em_id` (`cmp_em_id` ASC) ,
  INDEX `fk_compramp_tipocompramp` (`cmp_tcm_id` ASC) ,
  CONSTRAINT `fk_compramp_cmp_em_id`
    FOREIGN KEY (`cmp_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_compramp_tipocompramp`
    FOREIGN KEY (`cmp_tcm_id` )
    REFERENCES `ejogos`.`tipocompramp` (`tcm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`custosfixo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`custosfixo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`custosfixo` (
  `cf_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `cf_em_id` INT(11) NOT NULL ,
  `cf_vlTreinamento` DECIMAL(15,2) NULL DEFAULT NULL ,
  `cf_vlEstMP` DECIMAL(15,2) NULL DEFAULT NULL ,
  `cf_vlDeprecMaq` DECIMAL(15,2) NULL DEFAULT NULL ,
  `cf_vlDeprecPredio` DECIMAL(15,2) NULL DEFAULT NULL ,
  `cf_tu_id` INT(11) NULL DEFAULT NULL ,
  `cf_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `cf_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`cf_id`) ,
  INDEX `fk_custofixo_cf_em_id` (`cf_em_id` ASC) ,
  CONSTRAINT `fk_custofixo_cf_em_id`
    FOREIGN KEY (`cf_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`custovariavel`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`custovariavel` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`custovariavel` (
  `cv_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `cv_vlManutMaq` DECIMAL(15,2) NULL DEFAULT NULL ,
  `cv_em_id` INT(11) NOT NULL ,
  `cv_tu_id` INT(11) NULL DEFAULT NULL ,
  `cv_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `cv_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`cv_id`) ,
  INDEX `fk_custovariavel_cv_em_id` (`cv_em_id` ASC) ,
  CONSTRAINT `fk_custovariavel_cv_em_id`
    FOREIGN KEY (`cv_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`despesa`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`despesa` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`despesa` (
  `ds_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `ds_em_id` INT(11) NOT NULL ,
  `ds_vlInadimplencia` DECIMAL(15,2) NULL DEFAULT NULL ,
  `ds_tu_id` INT(11) NULL DEFAULT NULL ,
  `ds_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `ds_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`ds_id`) ,
  INDEX `fk_despesa_empresa_periodo1` (`ds_em_id` ASC) ,
  CONSTRAINT `fk_despesa_empresa_periodo1`
    FOREIGN KEY (`ds_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`estoquemp`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`estoquemp` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`estoquemp` (
  `es_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `es_em_id` INT(11) NOT NULL ,
  `es_vlConsMPA` DECIMAL(15,2) NULL DEFAULT NULL ,
  `es_vlConsMPB` DECIMAL(15,2) NULL DEFAULT NULL ,
  `es_vlCompEspMPA` DECIMAL(15,2) NULL DEFAULT NULL ,
  `es_vlCompEspMPB` DECIMAL(15,2) NULL DEFAULT NULL ,
  `es_vlCompProgMPA` DECIMAL(15,2) NULL DEFAULT NULL ,
  `es_vlCompProgMPB` DECIMAL(15,2) NULL DEFAULT NULL ,
  `es_tu_id` INT(11) NULL DEFAULT NULL ,
  `es_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `es_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`es_id`) ,
  INDEX `fk_estoquemp_es_em_id` (`es_em_id` ASC) ,
  INDEX `fk_estoquemp_materiaprima1` (`es_vlConsMPA` ASC) ,
  CONSTRAINT `fk_estoquemp_es_em_id`
    FOREIGN KEY (`es_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`finmaquinas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`finmaquinas` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`finmaquinas` (
  `fm_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `fm_em_id` INT(11) NOT NULL ,
  `fm_vlFinanciamento` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fm_vlAmortizacao` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fm_vlJuros` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fm_vlSaldoDevedor` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fm_tu_id` INT(11) NULL DEFAULT NULL ,
  `fm_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `fm_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`fm_id`) ,
  INDEX `fk_finmaquinas_fm_em_id` (`fm_em_id` ASC) ,
  CONSTRAINT `fk_finmaquinas_fm_em_id`
    FOREIGN KEY (`fm_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`fluxocaixa`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`fluxocaixa` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`fluxocaixa` (
  `fx_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `fx_em_id` INT(11) NOT NULL ,
  `fx_vlAplicacao` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlResgAplicacao` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlDescDuplicatas` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_pcJurosVdPz` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlDiversos` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlSaldoInicial` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlSaldoFinal` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlAtrasos` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_vlInadimplencia` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fx_tu_id` INT(11) NULL DEFAULT NULL ,
  `fx_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `fx_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`fx_id`) ,
  INDEX `fk_diversos_empresa_periodo1` (`fx_em_id` ASC) ,
  CONSTRAINT `fk_diversos_empresa_periodo1`
    FOREIGN KEY (`fx_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`folha_decisoes`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`folha_decisoes` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`folha_decisoes` (
  `fd_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `fd_em_id` INT(11) NOT NULL ,
  `fd_nrAdmitidos` INT(11) NULL DEFAULT '0' ,
  `fd_nrDemitidos` INT(11) NULL DEFAULT '0' ,
  `fd_nrSalario` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_pcTreinamento` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fd_pcParticipacao` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_vlCompProgMPA` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_vlCompProgMPB` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_nrPzPgtoMP` INT(11) NULL DEFAULT '0' ,
  `fd_pcNivelAtividade` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_pcProducaoExtra` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_pcProdutividade` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_nrCompMaqA` INT(11) NULL DEFAULT '0' ,
  `fd_nrCompMaqB` INT(11) NULL DEFAULT '0' ,
  `fd_nrCompMaqG` INT(11) NULL DEFAULT '0' ,
  `fd_nrVendMaqA` INT(11) NULL DEFAULT '0' ,
  `fd_nrVendMaqB` INT(11) NULL DEFAULT '0' ,
  `fd_nrVendMaqG` INT(11) NULL DEFAULT '0' ,
  `fd_vlEmprestimo` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_nrTpEmprestimo` INT(11) NULL DEFAULT '0' ,
  `fd_vlAplicacao` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_pcJurosVdPz` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_vlDiversos` DECIMAL(15,2) NULL DEFAULT '0.00' ,
  `fd_tu_id` INT(11) NULL DEFAULT NULL ,
  `fd_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `fd_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`fd_id`) ,
  INDEX `fk_folha_decisoes_empresa_periodo1` (`fd_em_id` ASC) ,
  CONSTRAINT `fk_folha_decisoes_empresa_periodo1`
    FOREIGN KEY (`fd_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`folhapagamento`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`folhapagamento` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`folhapagamento` (
  `fp_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `fp_em_id` INT(11) NOT NULL ,
  `fp_pcTreinamento` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fp_nrAdmitidos` INT(11) NULL DEFAULT NULL ,
  `fp_nrDemitidos` INT(11) NULL DEFAULT NULL ,
  `fp_vlSalarioBase` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fp_pcPartLucro` DECIMAL(15,2) NULL DEFAULT NULL ,
  `fp_tu_id` INT(11) NULL DEFAULT NULL ,
  `fp_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `fp_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`fp_id`) ,
  INDEX `fk_folhapagamento_fp_em_id` (`fp_em_id` ASC) ,
  CONSTRAINT `fk_folhapagamento_fp_em_id`
    FOREIGN KEY (`fp_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`setor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`setor` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`setor` (
  `se_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `se_noSetor` VARCHAR(20) NULL DEFAULT NULL ,
  PRIMARY KEY (`se_id`) ,
  UNIQUE INDEX `se_noSetor_UNIQUE` (`se_noSetor` ASC) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`gerente`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`gerente` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`gerente` (
  `ge_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `ge_tu_id` INT(11) NOT NULL ,
  `ge_nrMatric` VARCHAR(30) NULL DEFAULT NULL ,
  `ge_se_id` INT(11) NOT NULL ,
  `ge_e_id` INT(11) NOT NULL ,
  `ge_us_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`ge_id`) ,
  INDEX `ix_ge_tu_id` (`ge_tu_id` ASC) ,
  INDEX `fk_gerente_usuario` (`ge_us_id` ASC) ,
  INDEX `fk_gerente_setor1` (`ge_se_id` ASC) ,
  INDEX `fk_gerente_empresa1` (`ge_e_id` ASC) ,
  CONSTRAINT `fk_gerente_empresa1`
    FOREIGN KEY (`ge_e_id` )
    REFERENCES `ejogos`.`empresa` (`e_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_gerente_ge_tu_id`
    FOREIGN KEY (`ge_tu_id` )
    REFERENCES `ejogos`.`turma` (`tu_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_gerente_setor1`
    FOREIGN KEY (`ge_se_id` )
    REFERENCES `ejogos`.`setor` (`se_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_gerente_usuario`
    FOREIGN KEY (`ge_us_id` )
    REFERENCES `ejogos`.`usuario` (`us_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`maquina`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`maquina` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`maquina` (
  `m_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `m_em_id` INT(11) NOT NULL ,
  `m_tm_id` INT(11) NULL DEFAULT NULL ,
  `m_vlMaquina` DECIMAL(15,2) NULL DEFAULT NULL ,
  `m_tu_id` INT(11) NULL DEFAULT NULL ,
  `m_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `m_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`m_id`) ,
  INDEX `fk_mq_tm_id` (`m_tm_id` ASC) ,
  INDEX `fk_maquina_empresa_periodo1` (`m_em_id` ASC) ,
  CONSTRAINT `fk_maquina_empresa_periodo1`
    FOREIGN KEY (`m_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_mq_tm_id`
    FOREIGN KEY (`m_tm_id` )
    REFERENCES `ejogos`.`tipomaquina` (`tm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`maquina_periodo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`maquina_periodo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`maquina_periodo` (
  `mq_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `mq_em_id` INT(11) NOT NULL ,
  `mq_tm_id` INT(11) NOT NULL ,
  `mq_nrIdade` INT(11) NULL DEFAULT NULL ,
  `mq_vlContabil` DECIMAL(15,2) NULL DEFAULT NULL ,
  `mq_tu_id` INT(11) NULL DEFAULT NULL ,
  `mq_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `mq_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`mq_id`) ,
  INDEX `fk_maquina_mq_em_id` (`mq_em_id` ASC) ,
  INDEX `fk_maquina_periodo_tipomaquina1` (`mq_tm_id` ASC) ,
  INDEX `idx_nrIdade` (`mq_nrIdade` ASC) ,
  CONSTRAINT `fk_maquina_mq_em_id`
    FOREIGN KEY (`mq_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_maquina_periodo_tipomaquina1`
    FOREIGN KEY (`mq_tm_id` )
    REFERENCES `ejogos`.`tipomaquina` (`tm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`materiaprima`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`materiaprima` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`materiaprima` (
  `mp_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `mp_pe_id` INT(11) NOT NULL ,
  `mp_noTipo` ENUM('A','B') NULL DEFAULT NULL ,
  `mp_qtUnidadeProd` INT(11) NULL DEFAULT NULL ,
  `mp_vlPreco` DECIMAL(15,2) NULL DEFAULT NULL ,
  `mp_pcCompraEspecial` DECIMAL(15,2) NULL DEFAULT NULL ,
  `mp_tu_id` INT(11) NULL DEFAULT NULL ,
  `mp_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`mp_id`) ,
  INDEX `fk_materiaprima_mp_pe_id` (`mp_pe_id` ASC) ,
  CONSTRAINT `fk_materiaprima_mp_pe_id`
    FOREIGN KEY (`mp_pe_id` )
    REFERENCES `ejogos`.`periodo` (`pe_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`paramfixo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`paramfixo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`paramfixo` (
  `pf_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `pf_tu_id` INT(11) NULL DEFAULT NULL ,
  `pf_vlPredio` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pf_vlTerreno` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pf_pcVarMaquinas` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pf_pcJurosAtrasos` DECIMAL(15,2) NULL DEFAULT NULL ,
  PRIMARY KEY (`pf_id`) ,
  INDEX `fk_paramfixo_tu_id` (`pf_tu_id` ASC) ,
  CONSTRAINT `fk_paramfixo_tu_id`
    FOREIGN KEY (`pf_tu_id` )
    REFERENCES `ejogos`.`turma` (`tu_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`paramvariavel`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`paramvariavel` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`paramvariavel` (
  `pv_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `pv_pe_id` INT(11) NOT NULL ,
  `pv_vlDistLoc` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pv_vlDistExt` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pv_vlPropag` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pv_pcJuros` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pv_pcTR` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pv_tu_id` INT(11) NULL DEFAULT NULL ,
  `pv_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`pv_id`) ,
  INDEX `fk_paramvariavel_pv_pe_id` (`pv_pe_id` ASC) ,
  CONSTRAINT `fk_paramvariavel_pv_pe_id`
    FOREIGN KEY (`pv_pe_id` )
    REFERENCES `ejogos`.`periodo` (`pe_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`pessoal`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`pessoal` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`pessoal` (
  `ps_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `ps_em_id` INT(11) NOT NULL ,
  `ps_noSetor` ENUM('Adm','Producao','Vendas') NULL DEFAULT NULL ,
  `ps_qtEmpregados` INT(11) NULL DEFAULT NULL ,
  `ps_qtSalario` INT(11) NULL DEFAULT NULL ,
  `ps_tu_id` INT(11) NULL DEFAULT NULL ,
  `ps_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `ps_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`ps_id`) ,
  INDEX `fk_pessoal_ps_em_id` (`ps_em_id` ASC) ,
  CONSTRAINT `fk_pessoal_ps_em_id`
    FOREIGN KEY (`ps_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`pgtomp`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`pgtomp` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`pgtomp` (
  `pmp_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `pmp_vlPagar` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pmp_cmp_id` INT(11) NOT NULL ,
  `pmp_pago` ENUM('S','N') NULL DEFAULT NULL ,
  `pmp_pe_noPeriodo` DECIMAL(15,2) NULL DEFAULT NULL ,
  PRIMARY KEY (`pmp_id`) ,
  INDEX `fk_pgtomp_compramp1` (`pmp_cmp_id` ASC) ,
  CONSTRAINT `fk_pgtomp_compramp1`
    FOREIGN KEY (`pmp_cmp_id` )
    REFERENCES `ejogos`.`compramp` (`cmp_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`produtividade`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`produtividade` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`produtividade` (
  `pd_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `pd_em_id` INT(11) NOT NULL ,
  `pd_pcNivelAtividade` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pd_pcHoraExtra` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pd_pcIndProdutividade` DECIMAL(15,2) NULL DEFAULT NULL ,
  `pd_tu_id` INT(11) NULL DEFAULT NULL ,
  `pd_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `pd_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`pd_id`) ,
  INDEX `fk_produtividade_pd_em_id` (`pd_em_id` ASC) ,
  CONSTRAINT `fk_produtividade_pd_em_id`
    FOREIGN KEY (`pd_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`regiao`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`regiao` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`regiao` (
  `re_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `re_em_id` INT(11) NOT NULL ,
  `re_noRegiao` VARCHAR(100) NULL DEFAULT NULL ,
  `re_vlPrecoProd` DECIMAL(15,2) NULL DEFAULT NULL ,
  `re_nrPrazo` INT(11) NULL DEFAULT NULL ,
  `re_nrDemanda` INT(11) NULL DEFAULT NULL ,
  `re_nrMetasVenda` INT(11) NULL DEFAULT NULL ,
  `re_qtVendida` INT(11) NULL DEFAULT NULL ,
  `re_qtPropaganda` INT(11) NULL DEFAULT NULL ,
  `re_pcMargem` DECIMAL(15,2) NULL DEFAULT NULL ,
  `re_vlPreco` DECIMAL(15,2) NULL DEFAULT NULL ,
  `re_vlReceita` DECIMAL(15,2) NULL DEFAULT NULL ,
  `re_tu_id` INT(11) NULL DEFAULT NULL ,
  `re_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `re_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  `re_nrRegiao` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`re_id`) ,
  UNIQUE INDEX `ui_regiao_re_id` (`re_id` ASC) ,
  INDEX `ix_regiao_em_id` (`re_em_id` ASC) ,
  CONSTRAINT `fk_regiao_re_em_id`
    FOREIGN KEY (`re_em_id` )
    REFERENCES `ejogos`.`empresa_periodo` (`em_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`recebimento`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`recebimento` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`recebimento` (
  `rb_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `rb_re_id` INT(11) NULL DEFAULT NULL ,
  `rb_em_id` INT(11) NOT NULL ,
  `rb_tcm_id` INT(11) NOT NULL ,
  `rb_vlTipo` DECIMAL(15,2) NULL DEFAULT NULL ,
  `rb_tu_id` INT(11) NULL DEFAULT NULL ,
  `rb_nrPeriodo` INT(11) NULL DEFAULT NULL ,
  `rb_nrEmpresa` INT(11) NULL DEFAULT NULL ,
  `rb_nrRegiao` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`rb_id`) ,
  INDEX `fk_recebimento_rb_em_id` (`rb_em_id` ASC) ,
  INDEX `fk_recebimento_tipocompramp1` (`rb_tcm_id` ASC) ,
  INDEX `fk_recebimento_regiao` (`rb_re_id` ASC) ,
  CONSTRAINT `fk_recebimento_regiao`
    FOREIGN KEY (`rb_re_id` )
    REFERENCES `ejogos`.`regiao` (`re_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_recebimento_tipocompramp1`
    FOREIGN KEY (`rb_tcm_id` )
    REFERENCES `ejogos`.`tipocompramp` (`tcm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`tipo_emprestimo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`tipo_emprestimo` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`tipo_emprestimo` (
  `te_id` INT(11) NOT NULL ,
  `te_nrParcelas` INT(11) NULL DEFAULT NULL ,
  `te_nome` VARCHAR(45) NULL DEFAULT NULL ,
  PRIMARY KEY (`te_id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`tipo_prazo_venda`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`tipo_prazo_venda` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`tipo_prazo_venda` (
  `tpv_id` INT(11) NOT NULL ,
  `tpv_noTipo` VARCHAR(45) NULL DEFAULT NULL ,
  PRIMARY KEY (`tpv_id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

-- -----------------------------------------------------
-- Table `ejogos`.`variacao_valor_maquina`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `ejogos`.`variacao_valor_maquina` ;

CREATE  TABLE IF NOT EXISTS `ejogos`.`variacao_valor_maquina` (
  `vvm_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `vvm_pe_id` INT(11) NOT NULL ,
  `vvm_tm_id` INT(11) NOT NULL ,
  `vvm_pcVariacao` DECIMAL(15,2) NOT NULL ,
  PRIMARY KEY (`vvm_id`) ,
  INDEX `fk_variacao_periodo_pe_id` (`vvm_pe_id` ASC) ,
  INDEX `fk_variacao_tipomaquina_tm_id` (`vvm_tm_id` ASC) ,
  CONSTRAINT `fk_variacao_periodo_pe_id`
    FOREIGN KEY (`vvm_pe_id` )
    REFERENCES `ejogos`.`periodo` (`pe_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_variacao_tipomaquina_tm_id`
    FOREIGN KEY (`vvm_tm_id` )
    REFERENCES `ejogos`.`tipomaquina` (`tm_id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;

USE `ejogos`;

DELIMITER $$

USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`atualiza_compramp` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`atualiza_compramp`
AFTER UPDATE ON `ejogos`.`compramp`
FOR EACH ROW
begin
       declare tipo_compramp varchar(45);
       declare valor_tr DECIMAL(15, 2);
       declare vlCompEspMPA DECIMAL(15, 2);
       declare vlCompEspMPB DECIMAL(15, 2);
       declare vlCompProgMPA DECIMAL(15, 2);
       declare vlCompProgMPB DECIMAL(15, 2);
       declare total_programado DECIMAL(15, 2);
       declare total_especial DECIMAL(15, 2);
       
       declare periodo_id int;
       declare e_id int;
 
       
       select es_vlCompEspMPA into vlCompEspMPA from estoquemp where es_em_id = new.cmp_em_id;
       select es_vlCompEspMPB into vlCompEspMPB from estoquemp where es_em_id = new.cmp_em_id;
       select es_vlCompProgMPA into vlCompProgMPA from estoquemp where es_em_id = new.cmp_em_id;
       select es_vlCompProgMPB into vlCompProgMPB from estoquemp where es_em_id = new.cmp_em_id;
 
       select tcm_nome into tipo_compramp from tipocompramp where tcm_id = new.cmp_tcm_id;        
       select em_e_id into e_id from empresa_periodo where em_id = new.cmp_em_id;
       select em_pe_id into periodo_id from empresa_periodo where em_id = new.cmp_em_id;
       select pv_pcTR into valor_tr from paramvariavel where pv_pe_id = periodo_id;
       
       set total_programado = (vlCompEspMPA + vlCompEspMPB);
       set total_especial = (vlCompProgMPA + vlCompProgMPB);
       
       delete from pgtomp where pmp_cmp_id = new.cmp_id;
       
       if tipo_compramp = 'Prazo 0' then
           insert into pgtomp set pmp_vlPagar = total_programado, pmp_cmp_id = new.cmp_id, pmp_pago = 'S';
       end if;
       
       if tipo_compramp = 'Prazo 1' then
           insert into pgtomp set pmp_vlPagar = total_programado * ((valor_tr * (1 + valor_tr)) / (pow((1+valor_tr),2)-1)), pmp_cmp_id = new.cmp_id, pmp_pago = 'S';
           insert into pgtomp set pmp_vlPagar = total_programado * ((valor_tr * (1 + valor_tr)) / (pow((1+valor_tr),2)-1)), pmp_cmp_id = new.cmp_id, pmp_pago = 'N';
       end if;
       
       if tipo_compramp = 'Prazo 2' then
           insert into pgtomp set pmp_vlPagar = total_programado * ((valor_tr * pow((1 + valor_tr),2)) / (pow((1+valor_tr),2)-1)), pmp_cmp_id = new.cmp_id, pmp_pago = 'S';
           insert into pgtomp set pmp_vlPagar = total_programado * ((valor_tr * pow((1 + valor_tr),2)) / (pow((1+valor_tr),2)-1)), pmp_cmp_id = new.cmp_id, pmp_pago = 'N';
           insert into pgtomp set pmp_vlPagar = total_programado * ((valor_tr * pow((1 + valor_tr),2)) / (pow((1+valor_tr),2)-1)), pmp_cmp_id = new.cmp_id, pmp_pago = 'N';
 
       end if;
       
       insert into pgtomp set pmp_vlPagar = total_especial, pmp_cmp_id = new.cmp_id, pmp_pago = 'S';
       
   end$$


USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`nova_compra` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`nova_compra`
AFTER INSERT ON `ejogos`.`compramp`
FOR EACH ROW
begin
       insert into pgtomp set pmp_cmp_id = new.cmp_id, pmp_vlPagar = 0.0, pmp_pago = 'N';
       end$$


DELIMITER ;

DELIMITER $$

USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`nova_empresa_periodo` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`nova_empresa_periodo`
AFTER INSERT ON `ejogos`.`empresa_periodo`
FOR EACH ROW
begin
       declare tmid int;
       declare ctRegiao int;
       declare tcmId int;
       declare idPrazo int;
       
       select tcm_id into idPrazo from tipocompramp where tcm_nome = 'Prazo 0' and tcm_enTipo = 'V';
       
     -- tabela maquina
       select Max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Alfa';
       insert into maquina set m_em_id = new.em_id, m_tm_id = tmid, m_vlMaquina = 0.0, m_tu_id = new.em_tu_id, m_nrPeriodo = new.em_nrPeriodo, m_nrEmpresa = new.em_nrEmpresa;
       select Max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Beta';
       insert into maquina set m_em_id = new.em_id, m_tm_id = tmid, m_vlMaquina = 0.0, m_tu_id = new.em_tu_id, m_nrPeriodo = new.em_nrPeriodo, m_nrEmpresa = new.em_nrEmpresa;
       select Max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Gama';
       insert into maquina set m_em_id = new.em_id, m_tm_id = tmid, m_vlMaquina = 0.0, m_tu_id = new.em_tu_id, m_nrPeriodo = new.em_nrPeriodo, m_nrEmpresa = new.em_nrEmpresa;
     
     -- tabela produtividade
       insert into produtividade set pd_em_id = new.em_id, pd_pcNivelAtividade = 1.0, pd_pcHoraExtra = 1.0, pd_pcIndProdutividade = 1.0, pd_tu_id = new.em_tu_id, pd_nrPeriodo = new.em_nrPeriodo, pd_nrEmpresa = new.em_nrEmpresa;
       
       -- tabela emprestimo
       insert into emprestimo (ep_em_id, ep_vlMaxEmp, ep_tcm_id, ep_vlEmprestimo, ep_tu_id, ep_nrPeriodo, ep_nrEmpresa) values(new.em_id, 0.0,  (select max(tcm_id) from tipocompramp where tcm_enTipo = 'E'), 0.0, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
       
       -- tabela compramp
       insert into compramp (cmp_em_id, cmp_tcm_id, cmp_tu_id, cmp_nrPeriodo, cmp_nrEmpresa) values(new.em_id, (select max(tcm_id) from tipocompramp where tcm_enTipo = 'C'),new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
       
       -- tabela pessoal
        insert into pessoal set ps_em_id = new.em_id, ps_noSetor = 'Adm', ps_qtEmpregados = 20 , ps_qtSalario = 4, ps_tu_id = new.em_tu_id, ps_nrPeriodo = new.em_nrPeriodo, ps_nrEmpresa = new.em_nrEmpresa;
        insert into pessoal set ps_em_id = new.em_id, ps_noSetor = 'Vendas', ps_qtEmpregados = 10 , ps_qtSalario = 4, ps_tu_id = new.em_tu_id, ps_nrPeriodo = new.em_nrPeriodo, ps_nrEmpresa = new.em_nrEmpresa;
        insert into pessoal set ps_em_id = new.em_id, ps_noSetor = 'Producao', ps_qtEmpregados = 470 , ps_qtSalario = 1, ps_tu_id = new.em_tu_id, ps_nrPeriodo = new.em_nrPeriodo, ps_nrEmpresa = new.em_nrEmpresa;

        -- iniciar periodo 0

        if new.em_nrPeriodo = 0 then

            set ctRegiao = 1;
            while ctRegiao <=9 do
                if ctRegiao = 1 then
                    insert into regiao set re_em_id = new.em_id, re_noRegiao = ctRegiao, re_vlPrecoProd = 0.0, re_nrPrazo = idPrazo, re_nrDemanda = 1000, re_nrMetasVenda = 1000, re_qtVendida = 2000, re_qtPropaganda = 1, re_pcMargem = 0.05, re_vlPreco = 0.0, re_vlReceita = 0.0, re_tu_id = new.em_tu_id, re_nrPeriodo = new.em_nrPeriodo, re_nrEmpresa = new.em_nrEmpresa, re_nrRegiao = ctRegiao;
                else
                    insert into regiao set re_em_id = new.em_id, re_noRegiao = ctRegiao, re_vlPrecoProd = 0.0, re_nrPrazo = idPrazo, re_nrDemanda = 1000, re_nrMetasVenda = 1000, re_qtVendida = 1000, re_qtPropaganda = 1, re_pcMargem = 0.05, re_vlPreco = 0.0, re_vlReceita = 0.0, re_tu_id = new.em_tu_id, re_nrPeriodo = new.em_nrPeriodo, re_nrEmpresa = new.em_nrEmpresa, re_nrRegiao = ctRegiao;
                end if;
                set ctRegiao = ctRegiao + 1;
            end while;

            insert into folhapagamento set fp_em_id = new.em_id, fp_pcTreinamento = 0.05, fp_nrAdmitidos = 0, fp_nrDemitidos = 0, fp_vlSalarioBase = 1300.0, fp_pcPartLucro = 0.08, fp_tu_id = new.em_tu_id, fp_nrPeriodo = new.em_nrPeriodo, fp_nrEmpresa = new.em_nrEmpresa;
            
            insert into estoquemp set es_em_id = new.em_id, es_vlConsMPA = 30000.0, es_vlConsMPB = 20000.0, es_vlCompEspMPA = 30000.0, es_vlCompEspMPB = 20000.0, es_vlCompProgMPA = 30000.0, es_vlCompProgMPB = 20000.0, es_tu_id = new.em_tu_id, es_nrPeriodo = new.em_nrPeriodo, es_nrEmpresa = new.em_nrEmpresa;
            
            select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Alfa';
            insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 5, 500000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
            insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 10, 480000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
            insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 10, 480000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
            insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 20, 450000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
            insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 20, 450000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);

        else
        
            if new.em_nrPeriodo = 1 then
                select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Alfa';
                insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 5, 500000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
                insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 10, 480000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
                insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 10, 480000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
                insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 20, 450000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);
                insert into maquina_periodo(mq_em_id, mq_tm_id, mq_nrIdade, mq_vlContabil, mq_tu_id, mq_nrPeriodo, mq_nrEmpresa) values (new.em_id, tmid, 20, 450000, new.em_tu_id, new.em_nrPeriodo, new.em_nrEmpresa);            
            
            end if;
            set ctRegiao = 1;
            while ctRegiao <=9 do
                insert into regiao set re_em_id = new.em_id, re_noRegiao = ctRegiao, re_vlPrecoProd = 0.0, re_nrPrazo = idPrazo, re_nrDemanda = 0, re_nrMetasVenda = 0, re_qtVendida = 0, re_qtPropaganda = 0, re_pcMargem = 0.0, re_vlPreco = 0.0, re_vlReceita = 0.0, re_tu_id = new.em_tu_id, re_nrPeriodo = new.em_nrPeriodo, re_nrEmpresa = new.em_nrEmpresa, re_nrRegiao = ctRegiao;
                set ctRegiao = ctRegiao + 1;
            end while;
            
            insert into folhapagamento set fp_em_id = new.em_id, fp_pcTreinamento = 0.0, fp_nrAdmitidos = 0, fp_nrDemitidos = 0, fp_vlSalarioBase = 1300.0, fp_pcPartLucro = 0.0, fp_tu_id = new.em_tu_id, fp_nrPeriodo = new.em_nrPeriodo, fp_nrEmpresa = new.em_nrEmpresa;

            insert into estoquemp set es_em_id = new.em_id, es_vlConsMPA = 0.0, es_vlConsMPB = 0.0, es_vlCompEspMPA = 0.0, es_vlCompEspMPB = 0.0, es_vlCompProgMPA = 0.0, es_vlCompProgMPB = 0.0, es_tu_id = new.em_tu_id, es_nrPeriodo = new.em_nrPeriodo, es_nrEmpresa = new.em_nrEmpresa;


        end if;

        
       


        -- tabela compra_venda_maquina
        select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Alfa';
        insert into compra_venda_maquina(cvm_pe_id, cvm_em_id, cvm_tm_id, cvm_noTipoTransacao, cvm_nrQtde) values (new.em_pe_id, new.em_id, tmid, 'C', 0);
        insert into compra_venda_maquina(cvm_pe_id, cvm_em_id, cvm_tm_id, cvm_noTipoTransacao, cvm_nrQtde) values (new.em_pe_id, new.em_id, tmid, 'V', 0);
        select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Beta';
        insert into compra_venda_maquina(cvm_pe_id, cvm_em_id, cvm_tm_id, cvm_noTipoTransacao, cvm_nrQtde) values (new.em_pe_id, new.em_id, tmid, 'C', 0);
        insert into compra_venda_maquina(cvm_pe_id, cvm_em_id, cvm_tm_id, cvm_noTipoTransacao, cvm_nrQtde) values (new.em_pe_id, new.em_id, tmid, 'V', 0);
        select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Gama';
        insert into compra_venda_maquina(cvm_pe_id, cvm_em_id, cvm_tm_id, cvm_noTipoTransacao, cvm_nrQtde) values (new.em_pe_id, new.em_id, tmid, 'C', 0);
        insert into compra_venda_maquina(cvm_pe_id, cvm_em_id, cvm_tm_id, cvm_noTipoTransacao, cvm_nrQtde) values (new.em_pe_id, new.em_id, tmid, 'V', 0);
        
       -- tabela custosfixo
       insert into custosfixo set cf_em_id = new.em_id, cf_vlTreinamento = 0.0, cf_vlEstMP = 0.0, cf_vlDeprecMaq = 0.0, cf_vlDeprecPredio= 0.0, cf_tu_id = new.em_tu_id, cf_nrPeriodo = new.em_nrPeriodo, cf_nrEmpresa = new.em_nrEmpresa;
       
       -- tabela custovariavel
       insert into custovariavel set cv_vlManutMaq = 0.0, cv_em_id = new.em_id, cv_tu_id = new.em_tu_id, cv_nrPeriodo = new.em_nrPeriodo, cv_nrEmpresa = new.em_nrEmpresa;
       
       -- tabela despesa
       insert into despesa set ds_em_id = new.em_id, ds_vlInadimplencia = 0.0, ds_tu_id = new.em_tu_id, ds_nrPeriodo = new.em_nrPeriodo, ds_nrEmpresa = new.em_nrEmpresa;
        
       -- tabela fluxocaixa
       insert into fluxocaixa set fx_em_id = new.em_id, fx_vlAplicacao = 0.0, fx_vlResgAplicacao = 0.0, fx_vlDescDuplicatas = 0.0, fx_pcJurosVdPz = 0.04, fx_vlDiversos = 0.0, fx_vlSaldoInicial = 0.0, fx_vlSaldoFinal = 0.0, fx_vlAtrasos = 0.0, fx_vlInadimplencia = 0.0, fx_tu_id = new.em_tu_id, fx_nrPeriodo = new.em_nrPeriodo, fx_nrEmpresa = new.em_nrEmpresa;
       
       -- tabela folha_decisoes
       insert into folha_decisoes set fd_em_id = new.em_id, fd_nrAdmitidos = 0, fd_nrDemitidos = 0, fd_nrSalario = 0, fd_pcTreinamento = 0.0, fd_pcParticipacao = 0.0, fd_vlCompProgMPA = 0, fd_vlCompProgMPB = 0, fd_nrPzPgtoMP = 0, fd_pcNivelAtividade = 0.0, fd_pcProducaoExtra = 0.0, fd_pcProdutividade = 0.0, fd_nrCompMaqA = 0, fd_nrCompMaqB = 0, fd_nrCompMaqG = 0, fd_nrVendMaqA = 0, fd_nrVendMaqB = 0, fd_nrVendMaqG = 0,fd_vlEmprestimo = 0.0, fd_nrTpEmprestimo = 0, fd_vlAplicacao = 0.0, fd_pcJurosVdPz = 0.0, fd_vlDiversos = 0.0, fd_tu_id = new.em_tu_id, fd_nrPeriodo = new.em_nrPeriodo, fd_nrEmpresa = new.em_nrEmpresa;
       

       
   end$$


DELIMITER ;

DELIMITER $$

USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`atualiza_emprestimo` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`atualiza_emprestimo`
AFTER UPDATE ON `ejogos`.`emprestimo`
FOR EACH ROW
begin
       declare tipo_emprestimo varchar(45);
       declare valor_parcela DECIMAL(15, 2);
       declare valor_tr DECIMAL(15, 2);
       declare periodo_id int;
       declare empresa_id int;
       declare e_id int;
       declare count int;
       
       select tcm_nome into tipo_emprestimo from tipocompramp where tcm_id = new.ep_tcm_id;
       select em_e_id into e_id from empresa_periodo where em_id = new.ep_em_id;
       select em_pe_id into periodo_id from empresa_periodo where em_id = new.ep_em_id;
       
       select em_id into empresa_id from empresa_periodo where em_e_id = e_id and em_pe_id = periodo_id;
       select pv_pcTR into valor_tr from paramvariavel where pv_pe_id = periodo_id;
       
       delete from amortizacao where esp_em_id = new.ep_em_id;
 
       if tipo_emprestimo = 'Especial' then
           set periodo_id = periodo_id + 1;
           select em_id into empresa_id from empresa_periodo where em_pe_id = periodo_id and em_e_id = e_id;
           insert into amortizacao set esp_em_id = empresa_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = new.ep_vlEmprestimo,esp_vlJuros = new.ep_vlEmprestimo * valor_tr,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
       end if;
       
       if tipo_emprestimo = 'Programado 1' then
           set periodo_id = periodo_id + 1;
           select em_id into empresa_id from empresa_periodo where em_pe_id = periodo_id and em_e_id = e_id;
           insert into amortizacao set esp_em_id = empresa_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = new.ep_vlEmprestimo,esp_vlJuros = new.ep_vlEmprestimo * 0.1,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
       end if;
       
       if tipo_emprestimo = 'Programado 2' then
           set valor_parcela = new.ep_vlEmprestimo / 4;
 
           set periodo_id = periodo_id + 1;
           select em_id into empresa_id from empresa_periodo where em_pe_id = periodo_id and em_e_id = e_id;
           insert into amortizacao set esp_em_id = empresa_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = valor_parcela * (valor_tr + 0.02) * 4 ,esp_vlJuros = new.ep_vlEmprestimo/4 ,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
           
           set periodo_id = periodo_id + 2;
           select em_id into empresa_id from empresa_periodo where em_pe_id = periodo_id and em_e_id = e_id;
           insert into amortizacao set esp_em_id = empresa_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = valor_parcela * (valor_tr + 0.02) * 3 ,esp_vlJuros = valor_parcela ,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
           
           set periodo_id = periodo_id + 3;
           select em_id into empresa_id from empresa_periodo where em_pe_id = periodo_id and em_e_id = e_id;
           insert into amortizacao set esp_em_id = empresa_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = valor_parcela * (valor_tr + 0.02) * 2 ,esp_vlJuros = valor_parcela ,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
           
           set periodo_id = periodo_id + 4;
           select em_id into empresa_id from empresa_periodo where em_pe_id = periodo_id and em_e_id = e_id;
           insert into amortizacao set esp_em_id = empresa_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = valor_parcela * (valor_tr + 0.02) * 1 ,esp_vlJuros = valor_parcela ,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
       end if;
       
   end$$


USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`novo_emprestimo` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`novo_emprestimo`
AFTER INSERT ON `ejogos`.`emprestimo`
FOR EACH ROW
begin
       insert into amortizacao set esp_em_id = new.ep_em_id, esp_ep_id = new.ep_id, esp_tcm_id = new.ep_tcm_id, esp_vlEmprestimo = 0.0, esp_vlAmortizacao = 0.0,esp_vlJuros = 0.0,esp_vlSaldoDevedor = 0.0, esp_tu_id = new.ep_tu_id, esp_nrPeriodo = new.ep_nrPeriodo, esp_nrEmpresa = new.ep_nrEmpresa;
       end$$


DELIMITER ;

DELIMITER $$

USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`novo_periodo` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`novo_periodo`
AFTER INSERT ON `ejogos`.`periodo`
FOR EACH ROW
begin
       declare ctPeriodo int;
       declare ctEmpresa int;
       declare tmid int;
 
       -- tabela empresa_periodo
       set ctEmpresa = 1;
       while ctEmpresa <=8 do
           insert into empresa_periodo set em_pe_id = new.pe_id, em_nome = ctEmpresa, em_e_id = ctEmpresa, em_tu_id = new.pe_tu_id, em_nrPeriodo = new.pe_nrPeriodo, em_nrEmpresa = ctEmpresa;
               set ctEmpresa = ctEmpresa + 1;
       end while;

    -- tabela paramvariavel
           insert into paramvariavel set pv_pe_id = new.pe_id, pv_vlDistLoc = 25.0, pv_vlDistExt = 50.0, pv_vlPropag = 10000, pv_pcJuros = 0.04, pv_pcTR = 0.04, pv_tu_id = new.pe_tu_id, pv_nrPeriodo = new.pe_nrPeriodo;
           
        -- tabela variacao_valor_maquina
        select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Alfa';
        insert into variacao_valor_maquina(vvm_pe_id, vvm_tm_id, vvm_pcVariacao) values (new.pe_id, tmid, 0.0);
        select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Beta';
        insert into variacao_valor_maquina(vvm_pe_id, vvm_tm_id, vvm_pcVariacao) values (new.pe_id, tmid, 0.0);
        select max(tm_id) into tmid from tipomaquina where tm_noTipo = 'Gama';
        insert into variacao_valor_maquina(vvm_pe_id, vvm_tm_id, vvm_pcVariacao) values (new.pe_id, tmid, 0.0);
       
   end$$


DELIMITER ;

DELIMITER $$

USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`atualiza_regiao` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`atualiza_regiao`
AFTER UPDATE ON `ejogos`.`regiao`
FOR EACH ROW
begin
   declare idTcm int;
   declare noPrazo varchar(45);
   declare idEmpresa int;
   declare nrPeriodo int;
   declare vlParcela DECIMAL(15, 2);
   declare nrParcela int;
   declare pcJuros DECIMAL(15, 2);
   
   delete from recebimento where rb_re_id = new.re_id;
   
   select tcm_noParc into nrParcela from tipocompramp where tcm_id = new.re_nrPrazo;
   select fx_pcJurosVdPz into pcJuros from fluxocaixa where fx_em_id = new.re_em_id;
   
   if pcJuros > 0 then
       set vlParcela = new.re_vlPreco*((pcJuros* pow(1+pcJuros,nrParcela-1))/((pow(1+pcJuros,nrParcela))-1));
   else
       set vlParcela = new.re_vlPreco/nrParcela;
   end if;
   
   -- =B51*((0,04*(1+0,04)^(M52-1))/(((1+0,04)^M52)-1))
 
   select tcm_id into idTcm from tipocompramp where tcm_enTipo = 'V' and tcm_nome = 'Prazo 0';
   if (idTcm = new.re_nrPrazo) then
       insert into recebimento set rb_re_id = new.re_id, rb_em_id = new.re_em_id, rb_tcm_id = idTcm, rb_vlTipo = vlParcela, rb_tu_id = new.re_tu_id, rb_nrPeriodo = new.re_nrPeriodo, rb_nrEmpresa = new.re_nrEmpresa, rb_nrRegiao = new.re_nrRegiao;
   else
       insert into recebimento set rb_re_id = new.re_id, rb_em_id = new.re_em_id, rb_tcm_id = idTcm, rb_vlTipo = 0.0, rb_tu_id = new.re_tu_id, rb_nrPeriodo = new.re_nrPeriodo, rb_nrEmpresa = new.re_nrEmpresa, rb_nrRegiao = new.re_nrRegiao;
   end if;
 
       
       if new.re_nrPeriodo < 12 then
           select tcm_id into idTcm from tipocompramp where tcm_enTipo = 'V' and tcm_nome = 'Prazo 1';
           if (idTcm = new.re_nrPrazo) then
               insert into recebimento set rb_re_id = new.re_id, rb_em_id = new.re_em_id, rb_tcm_id = new.re_nrPrazo, rb_vlTipo = vlParcela, rb_tu_id = new.re_tu_id, rb_nrPeriodo = new.re_nrPeriodo, rb_nrEmpresa = new.re_nrEmpresa, rb_nrRegiao = new.re_nrRegiao;
               set nrPeriodo = new.re_nrPeriodo + 1;
               select em_id into idEmpresa from empresa_periodo where em_tu_id = new.re_tu_id and em_nrPeriodo = nrPeriodo and em_nrEmpresa = new.re_nrEmpresa;
               insert into recebimento set rb_re_id = new.re_id, rb_em_id = new.re_em_id, rb_tcm_id = new.re_nrPrazo, rb_vlTipo = vlParcela, rb_tu_id = new.re_tu_id, rb_nrPeriodo = nrPeriodo, rb_nrEmpresa = new.re_nrEmpresa, rb_nrRegiao = new.re_nrRegiao;
           else
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, new.re_em_id, idTcm, 0.0, new.re_tu_id, new.re_nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
               set nrPeriodo = new.re_nrPeriodo + 1;
               select em_id into idEmpresa from empresa_periodo where em_tu_id = new.re_tu_id and em_nrPeriodo = nrPeriodo and em_nrEmpresa = new.re_nrEmpresa;
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, idEmpresa, idTcm, 0.0, new.re_tu_id, nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
           end if;
       end if;
           
       if new.re_nrPeriodo < 11 then
           select tcm_id into idTcm from tipocompramp where tcm_enTipo = 'V' and tcm_nome = 'Prazo 2';
           if (idTcm = new.re_nrPrazo) then
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, new.re_em_id, idTcm, vlParcela, new.re_tu_id, new.re_nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
               set nrPeriodo = new.re_nrPeriodo + 1;
               select em_id into idEmpresa from empresa_periodo where em_tu_id = new.re_tu_id and em_nrPeriodo = nrPeriodo and em_nrEmpresa = new.re_nrEmpresa;
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, idEmpresa, idTcm, vlParcela, new.re_tu_id, nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
               set nrPeriodo = new.re_nrPeriodo + 2;
               select em_id into idEmpresa from empresa_periodo where em_tu_id = new.re_tu_id and em_nrPeriodo = nrPeriodo and em_nrEmpresa = new.re_nrEmpresa;
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, idEmpresa, idTcm, vlParcela, new.re_tu_id, nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
           else
               select tcm_id into idTcm from tipocompramp where tcm_enTipo = 'V' and tcm_nome = 'Prazo 2';
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, new.re_em_id, idTcm, 0.0, new.re_tu_id, new.re_nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
               set nrPeriodo = new.re_nrPeriodo + 1;
               select em_id into idEmpresa from empresa_periodo where em_tu_id = new.re_tu_id and em_nrPeriodo = nrPeriodo and em_nrEmpresa = new.re_nrEmpresa;
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, idEmpresa, idTcm, 0.0, new.re_tu_id, nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
               set nrPeriodo = new.re_nrPeriodo + 2;
               select em_id into idEmpresa from empresa_periodo where em_tu_id = new.re_tu_id and em_nrPeriodo = nrPeriodo and em_nrEmpresa = new.re_nrEmpresa;
               insert into recebimento (rb_re_id, rb_em_id, rb_tcm_id, rb_vlTipo, rb_tu_id, rb_nrPeriodo, rb_nrEmpresa, rb_nrRegiao) values (new.re_id, idEmpresa, idTcm, 0.0, new.re_tu_id, nrPeriodo, new.re_nrEmpresa, new.re_nrRegiao);
           end if;
       end if;
       
end$$


DELIMITER ;

DELIMITER $$

USE `ejogos`$$
DROP TRIGGER IF EXISTS `ejogos`.`nova_turma` $$
USE `ejogos`$$
CREATE
DEFINER=`root`@`localhost`
TRIGGER `ejogos`.`nova_turma`
AFTER INSERT ON `ejogos`.`turma`
FOR EACH ROW
begin
       declare ctPeriodo int;
 
       -- tabela paramfixo
           insert into paramfixo set pf_tu_id = new.tu_id, pf_vlPredio = 5440000.0, pf_vlTerreno = 1200000.0, pf_pcVarMaquinas = 0.2, pf_pcJurosAtrasos = 0.0;
           
       -- tabela periodo
       set ctPeriodo = 0;
       while ctPeriodo <=12 do
           if ctPeriodo = 1 then
               insert into periodo set pe_tu_id = new.tu_id, pe_noPeriodo = ctPeriodo, pe_noStatus = 'Aberto', pe_nrPeriodo = ctPeriodo;
               set ctPeriodo = ctPeriodo + 1;
           else
               insert into periodo set pe_tu_id = new.tu_id, pe_noPeriodo = ctPeriodo, pe_noStatus = 'Fechado', pe_nrPeriodo = ctPeriodo;
               set ctPeriodo = ctPeriodo + 1;
           end if;
       end while;
       
   end$$


DELIMITER ;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;