package entidades;

import dao.EmpresaPeriodoDAO;
import dao.FluxocaixaDAO;
import dao.FolhaPagamentoDAO;
import dao.JogosDAOException;
import dao.ParamFixoDAO;
import dao.ParamVariavelDAO;
import dao.PeriodoDAO;
import dao.ProdutividadeDAO;


/**
 *
 * @author rafael
 */
public class Despesa {

    private int des_em_id;

    /**
     *
     * @param des_em_id
     */
    public Despesa(int des_em_id){
        this.des_em_id = des_em_id;
    }

    /**
     *
     * @return
     */
    public int getDes_em_id() {
        return des_em_id;
    }

    /**
     *
     * @param des_em_id
     */
    public void setDes_em_id(int des_em_id) {
        this.des_em_id = des_em_id;
    }

    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public double despesasVendas() throws JogosDAOException{
        double despesasVendas = 0.0;
        EmpresaPeriodoDAO emDAO = new EmpresaPeriodoDAO();
        EmpresaPeriodo em = emDAO.empresaById(this.des_em_id);
        PeriodoDAO peDAO = new PeriodoDAO();
        Periodo pe = peDAO.periodoById(em.getEm_pe_id());
        ParamFixoDAO pfDAO = new ParamFixoDAO();
        ParamFixo pf = pfDAO.pfByTuId(pe.getPe_tu_id());
        FolhaPagamentoDAO fpDAO = new FolhaPagamentoDAO();
        FolhaPagamento fp = fpDAO.getFolhaObj(this.des_em_id);
        EstoqueProdutoAcabado epa = new EstoqueProdutoAcabado(this.des_em_id);
        FluxocaixaDAO fxDAO = new FluxocaixaDAO();
        Fluxocaixa fx = fxDAO.getByEmPr(this.des_em_id);
        despesasVendas =  fp.totalSalario("Vendas") + epa.estocagemProdutoAcabado() + (pf.depreciacaoPredio() * 0.1) + fx.getFx_vlInadimplencia();
        return despesasVendas;
    }

    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public double despesasAdm() throws JogosDAOException{
        double despesasAdm = 0.0;
        EmpresaPeriodoDAO emDAO = new EmpresaPeriodoDAO();
        EmpresaPeriodo em = emDAO.empresaById(this.des_em_id);
        PeriodoDAO peDAO = new PeriodoDAO();
        Periodo pe = peDAO.periodoById(em.getEm_pe_id());
        ParamFixoDAO pfDAO = new ParamFixoDAO();
        ParamFixo pf = pfDAO.pfByTuId(pe.getPe_tu_id());
        FolhaPagamentoDAO fpDAO = new FolhaPagamentoDAO();
        FolhaPagamento fp = fpDAO.getFolhaObj(this.des_em_id);
        despesasAdm =  fp.totalSalario("Adm") + (pf.depreciacaoPredio() * 0.2);
        return despesasAdm;
    }

    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public double despesasFinLiq() throws JogosDAOException{
        double despesasFinLiq = 0.0;
        EmpresaPeriodoDAO emDAO = new EmpresaPeriodoDAO();
        EmpresaPeriodo em = emDAO.empresaById(this.des_em_id);
        PeriodoDAO peDAO = new PeriodoDAO();
        Periodo pe = peDAO.periodoById(em.getEm_pe_id());
        ParamFixoDAO pfDAO = new ParamFixoDAO();
        ParamFixo pf = pfDAO.pfByTuId(pe.getPe_tu_id());
        ParamVariavelDAO pvDAO = new ParamVariavelDAO();
        ParamVariavel pv = pvDAO.listaByPeriodo(em.getEm_pe_id());
        FluxocaixaDAO fxDAO = new FluxocaixaDAO();
        Fluxocaixa fx = fxDAO.getByEmPr(this.des_em_id);
        fxDAO = new FluxocaixaDAO();
        Fluxocaixa fxAnterior = fxDAO.getByEmPr(em.empresaPeriodoAnterior());
        despesasFinLiq = (fx.getFx_vlAtrasos() * pf.getPf_pcJurosAtrasos()) - (fxAnterior.getFx_vlAplicacao() * (pv.getPv_pcJuros() + 0.01));
        return despesasFinLiq;
    }

    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public double despesasFixasRateadas() throws JogosDAOException{
        double despesasFixasRateadas = 0.0;
        ProdutividadeDAO prDAO = new ProdutividadeDAO();
        Produtividade pr = prDAO.getById(this.des_em_id);
        despesasFixasRateadas = this.totalDespesas()/ pr.producaoFinal();
        return despesasFixasRateadas;
    }

    /**
     *
     * @return
     * @throws JogosDAOException
     */
    public double totalDespesas() throws JogosDAOException{
        double totalDespesas = 0.0;
        totalDespesas = this.despesasVendas() + this.despesasFinLiq() + this.despesasAdm();
        return totalDespesas;
    }

/*    public static void main (String args[]) throws JogosDAOException{
        Despesa des = new Despesa(9);
        System.out.println(des.despesasFixasRateadas());
    }*/
    
}